Module instructions

Module instructions 

This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.

https://github.com/codama-idl/codama

Re-exports

pub use self::assert_account_data::*;
pub use self::assert_account_data_multi::*;
pub use self::assert_account_delta::*;
pub use self::assert_account_info::*;
pub use self::assert_account_info_multi::*;
pub use self::assert_bubblegum_tree_config_account::*;
pub use self::assert_merkle_tree_account::*;
pub use self::assert_mint_account::*;
pub use self::assert_mint_account_multi::*;
pub use self::assert_stake_account::*;
pub use self::assert_stake_account_multi::*;
pub use self::assert_sysvar_clock::*;
pub use self::assert_token_account::*;
pub use self::assert_token_account_multi::*;
pub use self::assert_upgradeable_loader_account::*;
pub use self::assert_upgradeable_loader_account_multi::*;
pub use self::memory_close::*;
pub use self::memory_write::*;

Modules

assert_account_data
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_account_data_multi
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_account_delta
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_account_info
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_account_info_multi
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_bubblegum_tree_config_account
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_merkle_tree_account
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_mint_account
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_mint_account_multi
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_stake_account
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_stake_account_multi
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_sysvar_clock
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_token_account
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_token_account_multi
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_upgradeable_loader_account
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
assert_upgradeable_loader_account_multi
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
memory_close
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
memory_write
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.