pub struct AssertAccountDataInstructionArgs {
pub log_level: LogLevel,
pub offset: CompactU64,
pub assertion: DataValueAssertion,
}Fields
log_level: LogLeveloffset: CompactU64assertion: DataValueAssertionTrait Implementations
Sourceimpl BorshDeserialize for AssertAccountDataInstructionArgs
impl BorshDeserialize for AssertAccountDataInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AssertAccountDataInstructionArgs
impl Clone for AssertAccountDataInstructionArgs
Sourcefn clone(&self) -> AssertAccountDataInstructionArgs
fn clone(&self) -> AssertAccountDataInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AssertAccountDataInstructionArgs
impl PartialEq for AssertAccountDataInstructionArgs
Sourcefn eq(&self, other: &AssertAccountDataInstructionArgs) -> bool
fn eq(&self, other: &AssertAccountDataInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssertAccountDataInstructionArgs
impl StructuralPartialEq for AssertAccountDataInstructionArgs