pub struct AssertAccountDataMultiInstructionArgs {
pub log_level: LogLevel,
pub assertions: AccountDataAssertions,
}Fields
log_level: LogLevelassertions: AccountDataAssertionsTrait Implementations
Sourceimpl BorshDeserialize for AssertAccountDataMultiInstructionArgs
impl BorshDeserialize for AssertAccountDataMultiInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AssertAccountDataMultiInstructionArgs
impl Clone for AssertAccountDataMultiInstructionArgs
Sourcefn clone(&self) -> AssertAccountDataMultiInstructionArgs
fn clone(&self) -> AssertAccountDataMultiInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AssertAccountDataMultiInstructionArgs
impl PartialEq for AssertAccountDataMultiInstructionArgs
Sourcefn eq(&self, other: &AssertAccountDataMultiInstructionArgs) -> bool
fn eq(&self, other: &AssertAccountDataMultiInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssertAccountDataMultiInstructionArgs
impl StructuralPartialEq for AssertAccountDataMultiInstructionArgs