pub struct AssertMintAccountMultiInstructionArgs {
pub log_level: LogLevel,
pub assertions: MintAccountAssertions,
}Fields
log_level: LogLevelassertions: MintAccountAssertionsTrait Implementations
Sourceimpl BorshDeserialize for AssertMintAccountMultiInstructionArgs
impl BorshDeserialize for AssertMintAccountMultiInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AssertMintAccountMultiInstructionArgs
impl Clone for AssertMintAccountMultiInstructionArgs
Sourcefn clone(&self) -> AssertMintAccountMultiInstructionArgs
fn clone(&self) -> AssertMintAccountMultiInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AssertMintAccountMultiInstructionArgs
impl PartialEq for AssertMintAccountMultiInstructionArgs
Sourcefn eq(&self, other: &AssertMintAccountMultiInstructionArgs) -> bool
fn eq(&self, other: &AssertMintAccountMultiInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssertMintAccountMultiInstructionArgs
impl StructuralPartialEq for AssertMintAccountMultiInstructionArgs