pub struct AssertSysvarClockInstructionArgs {
pub log_level: LogLevel,
pub assertion: SysvarClockAssertion,
}Fields
log_level: LogLevelassertion: SysvarClockAssertionTrait Implementations
Sourceimpl BorshDeserialize for AssertSysvarClockInstructionArgs
impl BorshDeserialize for AssertSysvarClockInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AssertSysvarClockInstructionArgs
impl Clone for AssertSysvarClockInstructionArgs
Sourcefn clone(&self) -> AssertSysvarClockInstructionArgs
fn clone(&self) -> AssertSysvarClockInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AssertSysvarClockInstructionArgs
impl PartialEq for AssertSysvarClockInstructionArgs
Sourcefn eq(&self, other: &AssertSysvarClockInstructionArgs) -> bool
fn eq(&self, other: &AssertSysvarClockInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssertSysvarClockInstructionArgs
impl StructuralPartialEq for AssertSysvarClockInstructionArgs