pub struct AssertTokenAccountInstructionArgs {
pub log_level: LogLevel,
pub assertion: TokenAccountAssertion,
}Fields
log_level: LogLevelassertion: TokenAccountAssertionTrait Implementations
Sourceimpl BorshDeserialize for AssertTokenAccountInstructionArgs
impl BorshDeserialize for AssertTokenAccountInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AssertTokenAccountInstructionArgs
impl Clone for AssertTokenAccountInstructionArgs
Sourcefn clone(&self) -> AssertTokenAccountInstructionArgs
fn clone(&self) -> AssertTokenAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AssertTokenAccountInstructionArgs
impl PartialEq for AssertTokenAccountInstructionArgs
Sourcefn eq(&self, other: &AssertTokenAccountInstructionArgs) -> bool
fn eq(&self, other: &AssertTokenAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssertTokenAccountInstructionArgs
impl StructuralPartialEq for AssertTokenAccountInstructionArgs