pub struct AssertTokenAccountMultiInstructionArgs {
pub log_level: LogLevel,
pub assertions: TokenAccountAssertions,
}Fields
log_level: LogLevelassertions: TokenAccountAssertionsTrait Implementations
Sourceimpl BorshDeserialize for AssertTokenAccountMultiInstructionArgs
impl BorshDeserialize for AssertTokenAccountMultiInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AssertTokenAccountMultiInstructionArgs
impl Clone for AssertTokenAccountMultiInstructionArgs
Sourcefn clone(&self) -> AssertTokenAccountMultiInstructionArgs
fn clone(&self) -> AssertTokenAccountMultiInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AssertTokenAccountMultiInstructionArgs
impl PartialEq for AssertTokenAccountMultiInstructionArgs
Sourcefn eq(&self, other: &AssertTokenAccountMultiInstructionArgs) -> bool
fn eq(&self, other: &AssertTokenAccountMultiInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssertTokenAccountMultiInstructionArgs
impl StructuralPartialEq for AssertTokenAccountMultiInstructionArgs