pub struct AssertUpgradeableLoaderAccountInstructionArgs {
pub log_level: LogLevel,
pub assertion: UpgradeableLoaderStateAssertion,
}Fields
log_level: LogLevelassertion: UpgradeableLoaderStateAssertionTrait Implementations
Sourceimpl BorshDeserialize for AssertUpgradeableLoaderAccountInstructionArgs
impl BorshDeserialize for AssertUpgradeableLoaderAccountInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AssertUpgradeableLoaderAccountInstructionArgs
impl Clone for AssertUpgradeableLoaderAccountInstructionArgs
Sourcefn clone(&self) -> AssertUpgradeableLoaderAccountInstructionArgs
fn clone(&self) -> AssertUpgradeableLoaderAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AssertUpgradeableLoaderAccountInstructionArgs
impl PartialEq for AssertUpgradeableLoaderAccountInstructionArgs
Sourcefn eq(&self, other: &AssertUpgradeableLoaderAccountInstructionArgs) -> bool
fn eq(&self, other: &AssertUpgradeableLoaderAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssertUpgradeableLoaderAccountInstructionArgs
impl StructuralPartialEq for AssertUpgradeableLoaderAccountInstructionArgs