pub struct AssertUpgradeableLoaderAccountMultiInstructionArgs {
pub log_level: LogLevel,
pub assertions: UpgradeableLoaderStateAssertions,
}Fields
log_level: LogLevelassertions: UpgradeableLoaderStateAssertionsTrait Implementations
Sourceimpl BorshDeserialize for AssertUpgradeableLoaderAccountMultiInstructionArgs
impl BorshDeserialize for AssertUpgradeableLoaderAccountMultiInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AssertUpgradeableLoaderAccountMultiInstructionArgs
impl Clone for AssertUpgradeableLoaderAccountMultiInstructionArgs
Sourcefn clone(&self) -> AssertUpgradeableLoaderAccountMultiInstructionArgs
fn clone(&self) -> AssertUpgradeableLoaderAccountMultiInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AssertUpgradeableLoaderAccountMultiInstructionArgs
impl PartialEq for AssertUpgradeableLoaderAccountMultiInstructionArgs
Sourcefn eq(&self, other: &AssertUpgradeableLoaderAccountMultiInstructionArgs) -> bool
fn eq(&self, other: &AssertUpgradeableLoaderAccountMultiInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssertUpgradeableLoaderAccountMultiInstructionArgs
impl StructuralPartialEq for AssertUpgradeableLoaderAccountMultiInstructionArgs