This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
Constants
- LIGHTHOUSE_
ID lighthouseprogram ID.
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
lighthouse program ID.