pub struct LEB128Vec<T: BorshSerialize + BorshDeserialize>(/* private fields */);Trait Implementations
Sourceimpl<T> BorshDeserialize for LEB128Vec<T>
impl<T> BorshDeserialize for LEB128Vec<T>
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<T> BorshSerialize for LEB128Vec<T>
impl<T> BorshSerialize for LEB128Vec<T>
Sourceimpl<T: Clone + BorshSerialize + BorshDeserialize> Clone for LEB128Vec<T>
impl<T: Clone + BorshSerialize + BorshDeserialize> Clone for LEB128Vec<T>
Sourceimpl<T: Debug + BorshSerialize + BorshDeserialize> Debug for LEB128Vec<T>
impl<T: Debug + BorshSerialize + BorshDeserialize> Debug for LEB128Vec<T>
Sourceimpl<T: PartialEq + BorshSerialize + BorshDeserialize> PartialEq for LEB128Vec<T>
impl<T: PartialEq + BorshSerialize + BorshDeserialize> PartialEq for LEB128Vec<T>
impl<T: Eq + BorshSerialize + BorshDeserialize> Eq for LEB128Vec<T>
impl<T: BorshSerialize + BorshDeserialize> StructuralPartialEq for LEB128Vec<T>